summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorDoug Gilbert <dgilbert@us.ibm.com>2015-01-26 14:41:54 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2015-02-28 05:49:51 -0600
commit29581aca6a1ed02d3374e5688e5f32fcb6f104bc (patch)
tree11f3ef76e83a0e18b313e2aa67b45292190e4b2a /src/include
parent9ca7f528d22e488c53d2dfbad32423806b47ddb0 (diff)
downloadblackbird-hostboot-29581aca6a1ed02d3374e5688e5f32fcb6f104bc.tar.gz
blackbird-hostboot-29581aca6a1ed02d3374e5688e5f32fcb6f104bc.zip
HTMGT: Implement OCC Reset
Change-Id: Icb713497d662d1ab55718409675bf4b23ac2c3ec RTC: 121721 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/15530 Tested-by: Jenkins Server Reviewed-by: Christopher Cain <cjcain@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include')
-rwxr-xr-xsrc/include/usr/htmgt/htmgt.H8
-rw-r--r--src/include/usr/htmgt/htmgt_reasoncodes.H3
-rw-r--r--src/include/usr/hwpf/hwp/occ/occ_common.H18
3 files changed, 16 insertions, 13 deletions
diff --git a/src/include/usr/htmgt/htmgt_reasoncodes.H b/src/include/usr/htmgt/htmgt_reasoncodes.H
index 98cdb5ecb..ade192d13 100644
--- a/src/include/usr/htmgt/htmgt_reasoncodes.H
+++ b/src/include/usr/htmgt/htmgt_reasoncodes.H
@@ -37,6 +37,8 @@ namespace HTMGT
HTMGT_MOD_MEMTHROTTLE = 0x03,
HTMGT_MOD_OCCMGR_SET_STATE = 0x04,
HTMGT_MOD_OCC_SET_STATE = 0x05,
+ HTMGT_MOD_PROCESS_OCC_RESET = 0x06,
+ HTMTG_MOD_OCC_RESET = 0x07,
HTMGT_MOD_OCC_POLL = 0x76,
HTMGT_MOD_BAD_FRU_CALLOUTS = 0x7D,
HTMGT_MOD_MISMATCHING_SEVERITY = 0x7F,
@@ -78,6 +80,7 @@ namespace HTMGT
HTMGT_RC_ECMD_DBUF_COPY_FAIL = HTMGT_COMP_ID | 0x53,
HTMGT_RC_TARGET_NOT_FUNCTIONAL = HTMGT_COMP_ID | 0x54,
HTMGT_RC_OCC_MASTER_NOT_FOUND = HTMGT_COMP_ID | 0x55,
+ HTMGT_RC_OCC_RESET_THREHOLD = HTMGT_COMP_ID | 0x56,
HTMGT_RC_PCAP_CALC_COMPLETE = HTMGT_COMP_ID | 0xB9,
HTMGT_RC_ENERGYSCALE_FFDC = HTMGT_COMP_ID | 0xFD,
};
diff --git a/src/include/usr/htmgt/htmgt.H b/src/include/usr/htmgt/htmgt.H
index 28ead6252..de7cfd2fb 100755
--- a/src/include/usr/htmgt/htmgt.H
+++ b/src/include/usr/htmgt/htmgt.H
@@ -62,9 +62,9 @@ namespace HTMGT
* be reported, this interface will be called to trigger
* HTMGT to collect and commit the error.
*
* @param[in] i_occTarget OCC target reporting the error
*/
- void processOccError(TARGETING::Target * i_occTarget);
+ void processOccError(TARGETING::Target * i_proc);
@@ -79,9 +79,9 @@ namespace HTMGT
* fails to go active, an unrecoverable error will be logged
* and the system will remain in safe mode.
*
* @param[in] i_failedOccTarget OCC target of the failed OCC
*/
- void processOccReset(TARGETING::Target * i_failedOccTarget);
+ void processOccReset(TARGETING::Target * i_proc);
@@ -62,9 +62,9 @@ namespace HTMGT
* HTMGT to collect and commit the error.
*
- * @param[in] i_occTarget OCC target reporting the error
+ * @param[in] i_proc Processor target of the OCC reporting the error
*/
@@ -79,9 +79,9 @@ namespace HTMGT
* and the system will remain in safe mode.
*
- * @param[in] i_failedOccTarget OCC target of the failed OCC
+ * @param[in] i_proc Proc target containing the failed OCC
*/
diff --git a/src/include/usr/hwpf/hwp/occ/occ_common.H b/src/include/usr/hwpf/hwp/occ/occ_common.H
index 824553961..ca7ab397f 100644
--- a/src/include/usr/hwpf/hwp/occ/occ_common.H
+++ b/src/include/usr/hwpf/hwp/occ/occ_common.H
@@ -92,18 +92,18 @@ namespace HBOCC
* @brief Execute procedures and steps required to load
* OCC data in a specified processor
*
* @param[in] i_target: target processor to load
* @param[in] i_homerPhysAddr: Physical address of current
* proc's homer
* @param[in] i_homerVirtAddr: Virtual address of current
* proc's homer
* @param[in] i_commonPhysAddr: Physical address of common
- * occ region
- * @return errlHndl_t Error log of loadOCC failed
+ * OCC region
+ * @return errlHndl_t Error log if loadOCC failed
*/
errlHndl_t loadOCC(TARGETING::Target* i_target,
- uint64_t i_homerPhysAddr,
- uint64_t i_homerVirtAddr,
+ uint64_t i_occImgPaddr,
+ uint64_t i_occImgVaddr,
uint64_t i_commonPhysAddr);
/**
OpenPOWER on IntegriCloud
@@ -92,18 +92,18 @@ namespace HBOCC
* OCC data in a specified processor
*
- * @param[in] i_target: target processor to load
- * @param[in] i_homerPhysAddr: Physical address of current
- * proc's homer
- * @param[in] i_homerVirtAddr: Virtual address of current
- * proc's homer
+ * @param[in] i_target: Target processor
+ * @param[in] i_occImgPaddr: Physical address of current
+ * proc's OCC image in the homer
+ * @param[in] i_occImgVaddr: Virtual address of current
+ * proc's OCC image int the homer
* @param[in] i_commonPhysAddr: Physical address of common